@@ -120,12 +120,6 @@ static const int signals[] = {
 #ifdef SIGQUIT
 	SIGQUIT,
 #endif
-#ifdef SIGILL
-	SIGILL,
-#endif
-#ifdef SIGABRT
-	SIGABRT,
-#endif
 #ifdef SIGFPE
 	SIGFPE,
 #endif
@@ -142,9 +136,6 @@ static const int signals[] = {
 	SIGUSR2,
 	/* POSIX.1-2001 */
 #endif
-#ifdef SIGBUS
-	SIGBUS,
-#endif
 #ifdef SIGXCPU
 	SIGXCPU,
 #endif
